@@ -1,5 +1,15 @@
+/**************************************************************************/
+/*  Klavaro - a flexible touch typing tutor                               */
+/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*                                                                        */
+/*  This program is free software, licensed under the terms of the GNU    */
+/*  General Public License as published by the Free Software Foundation,  */
+/*  which is also included in this package, in a file named "COPYING".    */
+/**************************************************************************/
 
-#define TEXTMAXLEN 4096
+#define TEXTMAXLEN 8000
+
+void callbacks_shield_set (gboolean state);
 
 void on_window_main_destroy (GtkObject * object, gpointer user_data);
 
@@ -7,9 +17,7 @@ void on_button_help_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_about_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_button_exit_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
+void on_button_exit_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_keyboard_clicked (GtkButton * button, gpointer user_data);
 
@@ -74,107 +82,7 @@ on_toggle_shift1_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 void
 on_toggle_shift2_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
-void on_but_space_clicked (GtkButton * button, gpointer user_data);
-
-void on_but1_clicked (GtkButton * button, gpointer user_data);
-
-void on_but3_clicked (GtkButton * button, gpointer user_data);
-
-void on_but13_clicked (GtkButton * button, gpointer user_data);
-
-void on_but2_clicked (GtkButton * button, gpointer user_data);
-
-void on_but10_clicked (GtkButton * button, gpointer user_data);
-
-void on_but9_clicked (GtkButton * button, gpointer user_data);
-
-void on_but8_clicked (GtkButton * button, gpointer user_data);
-
-void on_but7_clicked (GtkButton * button, gpointer user_data);
-
-void on_but6_clicked (GtkButton * button, gpointer user_data);
-
-void on_but5_clicked (GtkButton * button, gpointer user_data);
-
-void on_but4_clicked (GtkButton * button, gpointer user_data);
-
-void on_but12_clicked (GtkButton * button, gpointer user_data);
-
-void on_but11_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_1_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__11_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__10_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__9_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__8_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__7_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__6_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__5_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__4_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__3_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__2_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__1_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_3_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_12_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_11_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_10_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_9_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_8_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_7_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_6_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_5_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_4_clicked (GtkButton * button, gpointer user_data);
-
-void on_but_2_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___10_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___9_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___8_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___7_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___6_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___5_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___4_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___3_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___2_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___1_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___12_clicked (GtkButton * button, gpointer user_data);
-
-void on_but___11_clicked (GtkButton * button, gpointer user_data);
-
-void on_but__12_clicked (GtkButton * button, gpointer user_data);
-
-void on_but14_clicked (GtkButton * button, gpointer user_data);
+void on_virtual_key_clicked (GtkButton * button, gpointer user_data);
 
 void
 on_button_keyboard_close_clicked (GtkButton * button, gpointer user_data);
@@ -194,7 +102,8 @@ void on_window_tutor_destroy (GtkObject * object, gpointer user_data);
 void on_text_tutor_realize (GtkWidget * widget, gpointer user_data);
 
 void
-on_spinbutton_lesson_changed (GtkEditable * editable, gpointer user_data);
+on_spinbutton_lesson_value_changed (GtkSpinButton * spinbutton,
+				    gpointer user_data);
 
 void on_button_revert_lesson_clicked (GtkButton * button, gpointer user_data);
 
@@ -211,9 +120,17 @@ void on_button_tutor_intro_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_tutor_close_clicked (GtkButton * button, gpointer user_data);
 
+void on_button_tutor_font_clicked (GtkButton * button, gpointer user_data);
+
+void on_togglebutton_edit_basic_lesson_toggled
+	(GtkToggleButton * togglebutton, gpointer user_data);
+
 void
-on_checkbutton_beep_toggled            (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
+on_entry_custom_basic_lesson_activate (GtkEntry * entry, gpointer user_data);
+
+void
+on_checkbutton_beep_toggled (GtkToggleButton * togglebutton,
+			     gpointer user_data);
 
 gboolean
 on_entry_mesg_focus_out_event (GtkWidget * widget,
@@ -288,14 +205,8 @@ void on_window_hints_destroy (GtkObject * object, gpointer user_data);
 
 
 void
-on_fontselectiondialog_tutor_response  (GtkDialog       *dialog,
-                                        gint             response_id,
-                                        gpointer         user_data);
+on_fontselectiondialog_tutor_response (GtkDialog * dialog,
+				       gint response_id, gpointer user_data);
 
 void
-on_fontselectiondialog_tutor_destroy   (GtkObject       *object,
-                                        gpointer         user_data);
-
-void
-on_button_tutor_font_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
+on_fontselectiondialog_tutor_destroy (GtkObject * object, gpointer user_data);
