@@ -1,6 +1,15 @@
-#define DEFAULT_KEYBOARD "qwerty_br_abnt2"
+/**************************************************************************/
+/*  Klavaro - a flexible touch typing tutor                               */
+/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*                                                                        */
+/*  This program is free software, licensed under the terms of the GNU    */
+/*  General Public License as published by the Free Software Foundation,  */
+/*  which is also included in this package, in a file named "COPYING".    */
+/**************************************************************************/
 
-#define MAX_KEYBOARDS 100
+#define DEFAULT_KEYBOARD "dvorak_br"
+
+#define MAX_KEYBOARDS 200
 #define KEY_LINE_LEN (14+1)	/* 14 keys + 1 NULL char */
 
 #define UPSYM ((gunichar) 182)
@@ -43,7 +52,7 @@ void keyb_update_virtual_layout (void);
 
 void keyb_fill_layout_list (gint entry_type);
 
-void keyb_edit_key (GtkButton * button, const gchar * pix_file_name);
+void keyb_edit_key (GtkButton * button);
 
 void keyb_change_key (gunichar real_key);
 
@@ -56,7 +65,7 @@ gboolean keyb_force_edit_tab (gpointer data);
  */
 void hints_init (void);
 
-gchar * hints_string_from_charcode (gchar charcode);
+gchar *hints_string_from_charcode (gchar charcode);
 
 void hints_set_tips (void);
 
